package dev.fyloz.musicplayer.core.factory

import dev.fyloz.musicplayer.core.http.auth.AuthorizationData
import dev.fyloz.musicplayer.core.model.SearchResult
import dev.fyloz.musicplayer.core.model.SearchResultItem
import dev.fyloz.musicplayer.core.model.Song

typealias STR = String

class SongFactoryProxy {
    private val factories = mutableMapOf<String, SongFactory>()

    fun registerFactory(type: String, factory: SongFactory) {
        factories[type] = factory;
    }

    suspend fun search(query: String, auth: AuthorizationData): SearchResult {
        val results = mutableMapOf<String, Collection<SearchResultItem>>()
        factories.forEach { (type, factory) ->
            results[type] = factory.search(query, auth)
        }
        return results.toMap()
    }

    suspend fun create(type: String, id: String, songId: String, auth: AuthorizationData): Song =
        getFactory(type).create(id, songId, auth)

    private fun getFactory(type: String) = factories[type]!!;
}
