package dev.fyloz.musicplayer.core.http

import dev.fyloz.musicplayer.core.getAuthorizationData
import dev.fyloz.musicplayer.core.http.requests.CreateSongRequest
import dev.fyloz.musicplayer.core.logic.SongLogic
import io.ktor.server.application.*
import io.ktor.server.request.*
import io.ktor.server.response.*
import io.ktor.server.routing.*
import org.koin.ktor.ext.inject

fun Route.configureSongRoutes() {
    val logic by inject<SongLogic>()

    route("/song") {
        get("/") {
            call.respond(logic.getAll().toList())
        }

        get("/search") {
            val query = call.request.queryParameters["q"]!!
            val songs = logic.search(query, call.getAuthorizationData())
            call.respond(songs)
        }

        post {
            val request = call.receive<CreateSongRequest>()
            val song = logic.save(request.type, request.songId, call.getAuthorizationData())
            call.respond(song)
        }
    }
}
