package dev.fyloz.musicplayer.core.logic

import dev.fyloz.musicplayer.core.data.SongRepository
import dev.fyloz.musicplayer.core.factory.SongFactoryProxy
import dev.fyloz.musicplayer.core.http.auth.AuthorizationData
import dev.fyloz.musicplayer.core.model.SearchResult
import dev.fyloz.musicplayer.core.model.Song
import org.koin.core.component.KoinComponent
import org.koin.core.component.inject
import java.util.UUID

class SongLogic : KoinComponent {
    private val repository by inject<SongRepository>()
    private val songFactory by inject<SongFactoryProxy>()

    fun getAll() = repository.findAll()
    fun getById(id: String) = repository.findById(id)

    suspend fun search(query: String, auth: AuthorizationData): SearchResult {
        return songFactory.search(query, auth)
    }

    suspend fun save(type: String, songId: String, auth: AuthorizationData): Song {
        val id = generateId()
        val song = songFactory.create(type, id, songId, auth)
        repository.save(song)
        return song
    }

    private fun generateId() = UUID.randomUUID().toString()
}
