package dev.fyloz.musicplayer.modules

import dev.fyloz.musicplayer.core.KoinModule
import dev.fyloz.musicplayer.core.factory.SongFactory
import dev.fyloz.musicplayer.core.factory.SongFactoryProxy
import io.ktor.server.application.*
import io.ktor.server.config.*
import io.ktor.server.routing.*
import org.koin.ktor.ext.inject

abstract class Module(private val moduleName: String) {
    open fun setupDependencyInjection(module: KoinModule, config: ApplicationConfig) {
    }

    open fun configure(app: Application) {
        with(app) {
            val songFactoryProxy by inject<SongFactoryProxy>()
            songFactoryProxy.registerFactory(moduleName, getSongFactory())
        }
    }

    fun configureRoutes(routing: Routing) {
        with(routing) {
            route("/api/v1/$moduleName") {
                configureApiRoutes()
            }

            route("/module/$moduleName") {
                configureModuleRoutes()
            }
        }
    }

    open fun getAuthorizationData(call: ApplicationCall): Any? = null

    protected open fun Route.configureApiRoutes() {
    }

    protected open fun Route.configureModuleRoutes() {
    }

    protected abstract fun getSongFactory(): SongFactory
}
