package dev.fyloz.musicplayer.modules.spotify

import dev.fyloz.musicplayer.core.factory.SongFactory
import dev.fyloz.musicplayer.core.http.auth.AuthorizationData
import dev.fyloz.musicplayer.core.model.SearchResultItem
import dev.fyloz.musicplayer.core.model.Song

class SpotifySongFactory : SongFactory {
    private val apiProvider = SpotifyApiProvider()

    override suspend fun search(query: String, auth: AuthorizationData): Collection<SearchResultItem> {
        val apiSongs = apiProvider.search(query, "track", auth.accessToken)
        return apiSongs.map { SearchResultItem(it.id, it.name, it.artists.map { a -> a.name }) }
    }

    override suspend fun create(id: String, songId: String, auth: AuthorizationData): Song {
        val spotifyApiSong = apiProvider.getSongById(songId, auth.accessToken);
        return SpotifySong(id, songId, spotifyApiSong.name, spotifyApiSong.artists.map { it.name })
    }

    private val AuthorizationData.accessToken
        get() = getModuleData<SpotifyAuthorizationData>(SpotifyModule.moduleName).accessToken
}
